# encoding: utf-8

require 'spec_helper'


module MyEpisodes
  describe Cli, vcr: {cassette_name: 'my_episodes'} do
    let :io do
      StringIO.new
    end

    describe '-D / --dump' do
      let :argv do
        %w[--dump -u demo -p demo]
      end

      let :output do
        io.string.split("\n")
      end

      before do
        described_class.run(argv, io)
      end

      it 'dumps history to $stdout' do
        expect(output.grep(/Akame ga KILL!/)).to_not be_empty
        expect(output.grep(/Blake's 7/)).to_not be_empty
        expect(output.grep(/Doctor Who/)).to_not be_empty
        expect(output.grep(/Under the Dome/)).to_not be_empty
        expect(output.grep(/Wilfred \(US\)/)).to_not be_empty
        expect(output.size).to eq(587)
      end

      it 'includes headers' do
        expect(output.first).to eq('show;season;number;episode_name;acquired;watched')
      end

      context 'with -s / --separator' do
        let :argv do
          %w[--dump -u demo -p demo -s ':']
        end

        it 'uses given character as separator' do
          expect(output.grep(/.+:.+:.+/)).to_not be_empty
        end
      end
    end

    describe '-h / --help' do
      let :argv do
        %w[--help]
      end

      before do
        described_class.run(argv, io)
      end

      it 'prints usage' do
        expect(io.string).to match(/^Usage: /)
      end
    end

    describe 'without any action' do
      let :argv do
        []
      end

      before do
        described_class.run(argv, io)
      end

      it 'prints usage' do
        expect(io.string).to match(/^Usage: /)
      end
    end
  end
end
