# encoding: utf-8

require 'spec_helper'


module MyEpisodes
  describe Client do
    let :client do
      described_class.create('demo', 'demo')
    end

    after do
      client.logout
    end

    describe '#login' do
      let :client do
        described_class.new
      end

      context 'when given valid username and password', vcr: {cassette_name: 'login-fail'} do
        it 'does not raise an error' do
          expect { client.login('demo', 'demo') }.to_not raise_error
        end
      end

      context 'when given invalid username and password', vcr: {cassette_name: 'login-success'} do
        it 'raises an error' do
          expect { client.login('demo', 'this is wrong') }.to raise_error(AuthenticationError)
        end
      end
    end

    describe '#shows', vcr: {cassette_name: 'my_episodes'} do
      it 'parses the expected number of shows' do
        expect(client.shows.size).to eq(5)
      end

      it 'parses seasons as expected' do
        show = client.shows.find { |s| s.name == 'Doctor Who' }
        expect(show.seasons.size).to eq(22)
        show.seasons.each do |season|
          expect(season.name).to_not be_nil
          expect(season.name).to_not be_empty
        end
      end

      it 'parses episodes as expected' do
        show = client.shows.find { |s| s.name == 'Under the Dome' }
        seasons = show.seasons
        expect(seasons.size).to eq(2)
        expect(seasons.first.episodes.size).to eq(1)
        expect(seasons.last.episodes.size).to eq(11)
      end
    end
  end
end
