# encoding: utf-8

require 'spec_helper'


module MyEpisodes
  describe Season do
    let :season do
      described_class.new(show)
    end

    let :show do
      Show.new('Show')
    end

    describe '#create' do
      it 'sets name' do
        row = double(:row, text: 'Season #1')
        season.create(row)
        expect(season.name).to eq('Season #1')
      end

      it 'strips whitespace characters' do
        row = double(:row, text: "     Season #1\t\t\n")
        season.create(row)
        expect(season.name).to eq('Season #1')
      end

      it 'returns self' do
        expect(season.create(double(:row, text: 'Season #1'))).to eq(season)
      end
    end

    describe '#show' do
      it 'returns given show, but frozen' do
        expect(season.show).to eq(show)
        expect(season.show).to be_frozen
      end
    end

    describe '#<<' do
      it 'adds an Episode to list of episodes' do
        episode = Episode.new(season)
        season << episode
        expect(season.episodes.size).to eq(1)
        expect(season.episodes).to eq([episode])
      end
    end

    describe '#episodes' do
      it 'returns a frozen list of episodes' do
        expect(season.episodes).to be_frozen
      end
    end
  end
end
